clear
set mem 200m
set logtype text
set more off

cap log close
log using table1_suicides_summarystats, replace

use monthlydata

* Calculate share of fatalities in suicide attacks
egen x = sum(isr_suicide), by(year2)
egen y = sum(isr_tot), by(year2)
gen share_suicide = x/y
drop x y

egen x = sum(isr_suicide)
egen y = sum(isr_tot)
gen share_suicide_allyears = x/y
drop x y

* Calculate share of suicide attacks that were successful
egen numbIsui_succ_byyear = sum(numbIsui_succ), by(year2)
gen numbIsui_total  = numbIsui_succ + numbIsui_fail
egen numbIsui_total_byyear = sum(numbIsui_total), by(year2)
gen share_successful_byyear = numbIsui_succ_byyear /numbIsui_total_byyear

egen numbIsui_succ_allyears = sum(numbIsui_succ)
egen numbIsui_total_allyears = sum(numbIsui_total)
gen share_successful_allyears = numbIsui_succ_allyears/numbIsui_total_allyears

* Calculate average number of fatalities per successful suicide attack
egen isr_suicide_byyear = sum(isr_suicide), by(year2)
gen avg_isr_sui_per_sui_succ_byyear = isr_suicide_byyear/numbIsui_succ_byyear 
gen avg_isr_sui_per_sui_total_byyear = isr_suicide_byyear/numbIsui_total_byyear 

egen isr_suicide_allyears = sum(isr_suicide)
gen avg_isr_sui_persucc_allyears = isr_suicide_allyears/numbIsui_succ_allyears
gen avg_isr_sui_pertotal_allyears  = isr_suicide_allyears/numbIsui_total_allyears


* Table 1, Rows 1-5, columns 1-5
table year2, c(sum isr_tot sum isr_suicide mean share_suicide sum numbIsui_succ sum numbIsui_fail)

* Table 1, rows 1-5, TOTAL column
gen byte cons = 1
table cons, c(sum isr_tot sum isr_suicide mean share_suicide_allyears sum numbIsui_succ sum numbIsui_fail)

* Table 1, Rows 6-8, column 1-5
table year2, c(mean share_successful_byyear mean avg_isr_sui_per_sui_succ_byyear mean avg_isr_sui_per_sui_total_byyear) 

* Table 1, Rows 6-8, TOTAL column
table cons, c(mean share_successful_allyears mean avg_isr_sui_persucc_allyears mean avg_isr_sui_pertotal_allyears) 


log close
